==> onebapp-vue-dev-0.0.4.tgz: package/lib/backend/useEdge.js <==
import { getValueByPath, useQuery } from "./useQuery";
import { computed } from "vue";
export const useEdge = (name, query, options) => {
    const controller = useQuery(name, query, options);
    const connection = computed(() => {
        if (controller.data.value == null) {
            return null;
        }
        return getValueByPath(controller.data.value, options.connection);
    });
    const edges = computed(() => connection.value?.edges ?? []);
    const pageInfo = computed(() => connection.value?.pageInfo);
    if (typeof options.limit === "number" && options.limit > 0) {
        controller.variables.value = {
            ...controller.variables.value,
            limit: options.limit,
        };
    }
    const load = () => {
        if (controller.variables.value?.cursor) {
            controller.variables.value.cursor = null;
        }
        return controller.load();
    };
    return {
        ...controller,
        edges,
        // @ts-ignore
        nodes: computed(() => edges.value.map((edge) => edge.node)),
        totalCount: computed(() => connection.value?.count),
        hasMore: computed(() => {
            if (options.isBackward === true) {
                return pageInfo.value?.hasPreviousPage === true;
            }
            return pageInfo.value?.hasNextPage === true;
        }),
        load,
        loadMore() {
            const hasMore = options.isBackward === true
                ? pageInfo.value?.hasPreviousPage
                : pageInfo.value?.hasNextPage;
            if (hasMore !== true)
                return;
            if (controller.status.value == undefined) {
                return Promise.reject(new Error("Edge not loaded")); // controller.load(nextVariables); // TODO: merge results
            }
            const nextVariables = {
                ...controller.variables.value,
                cursor: pageInfo.value.endCursor,
            };
            if (options.isBackward === true) {
                nextVariables.cursor = pageInfo.value.startCursor;
            }
            return controller.loadMore(nextVariables, 
            // @ts-ignore
            (previousResult, { fetchMoreResult }) => {
                const nextConnection = getValueByPath(fetchMoreResult, options.connection);
                if (nextConnection.edges.length === 0) {
                    return previousResult;
                }
                const aggrResult = { ...previousResult };
                const pathItems = options.connection.split(".");
                aggrResult[pathItems[0]] = { ...aggrResult[pathItems[0]] };
                if (pathItems.length > 1) {
                    aggrResult[pathItems[0]][pathItems[1]] = {
                        ...aggrResult[pathItems[0]][pathItems[1]],
                    };
                    if (pathItems.length > 2) {
                        aggrResult[pathItems[0]][pathItems[1]][pathItems[2]] = {
                            ...aggrResult[pathItems[0]][pathItems[1]][pathItems[2]],
                        };
                        if (pathItems.length > 3) {
                            aggrResult[pathItems[0]][pathItems[1]][pathItems[2]][pathItems[3]] = {
                                ...aggrResult[pathItems[0]][pathItems[1]][pathItems[2]][pathItems[3]],
                            };
                        }
                    }
                }
                const aggrConnection = getValueByPath(aggrResult, options.connection);
                aggrConnection.pageInfo = { ...nextConnection.pageInfo };
                if (options.append !== false) {
                    aggrConnection.edges = [
                        ...aggrConnection.edges,
                        ...nextConnection.edges,
                    ];
                }
                else {
                    aggrConnection.edges = [...nextConnection.edges];
                }
                return aggrResult;
            });
        },
    };
};

==> onebapp-vue-dev-0.0.15.tgz: package/lib/backend/useEdge.js <==
import { getValueByPath, useQuery } from "./useQuery";
import { computed } from "vue";
export const useEdge = (name, query, options) => {
    const controller = useQuery(name, query, options);
    const connection = computed(() => {
        if (controller.data.value == null) {
            return null;
        }
        return getValueByPath(controller.data.value, options.connection);
    });
    const edges = computed(() => connection.value?.edges ?? []);
    const pageInfo = computed(() => connection.value?.pageInfo);
    if (typeof options.limit === "number" && options.limit > 0) {
        // @ts-ignore
        controller.variables.value = { ...controller.variables.value, limit: options.limit };
    }
    const load = () => {
        if (controller.variables.value != null) {
            // @ts-ignore
            controller.variables.value.cursor = null;
        }
        return controller.load();
    };
    return {
        ...controller,
        edges,
        // @ts-ignore
        nodes: computed(() => edges.value.map((edge) => edge.node)),
        totalCount: computed(() => connection.value?.count),
        hasMore: computed(() => {
            if (options.isBackward === true) {
                return pageInfo.value?.hasPreviousPage === true;
            }
            return pageInfo.value?.hasNextPage === true;
        }),
        load,
        loadMore() {
            const hasMore = options.isBackward === true
                ? pageInfo.value?.hasPreviousPage
                : pageInfo.value?.hasNextPage;
            if (hasMore !== true)
                return;
            if (controller.status.value == undefined) {
                return Promise.reject(new Error("Edge not loaded")); // controller.load(nextVariables); // TODO: merge results
            }
            const nextVariables = {
                ...controller.variables.value,
                cursor: pageInfo.value.endCursor,
            };
            if (options.isBackward === true) {
                nextVariables.cursor = pageInfo.value.startCursor;
            }
            return controller.loadMore(
            // @ts-ignore
            nextVariables, 
            // @ts-ignore
            (previousResult, { fetchMoreResult }) => {
                const nextConnection = getValueByPath(fetchMoreResult, options.connection);
                if (nextConnection.edges.length === 0) {
                    return previousResult;
                }
                const aggrResult = { ...previousResult };
                const pathItems = options.connection.split(".");
                aggrResult[pathItems[0]] = { ...aggrResult[pathItems[0]] };
                if (pathItems.length > 1) {
                    aggrResult[pathItems[0]][pathItems[1]] = {
                        ...aggrResult[pathItems[0]][pathItems[1]],
                    };
                    if (pathItems.length > 2) {
                        aggrResult[pathItems[0]][pathItems[1]][pathItems[2]] = {
                            ...aggrResult[pathItems[0]][pathItems[1]][pathItems[2]],
                        };
                        if (pathItems.length > 3) {
                            aggrResult[pathItems[0]][pathItems[1]][pathItems[2]][pathItems[3]] = {
                                ...aggrResult[pathItems[0]][pathItems[1]][pathItems[2]][pathItems[3]],
                            };
                        }
                    }
                }
                const aggrConnection = getValueByPath(aggrResult, options.connection);
                aggrConnection.pageInfo = { ...nextConnection.pageInfo };
                if (options.append !== false) {
                    aggrConnection.edges = [
                        ...aggrConnection.edges,
                        ...nextConnection.edges,
                    ];
                }
                else {
                    aggrConnection.edges = [...nextConnection.edges];
                }
                return aggrResult;
            });
        },
    };
};
